==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/BasicZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.client.plant.PeashooterRenderState;
import net.db64.homelawnsecurity.entity.custom.plant.PeashooterEntity;
import net.db64.homelawnsecurity.entity.custom.zombie.BasicZombieEntity;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class BasicZombieRenderer extends class_927<BasicZombieEntity, BasicZombieRenderState, BasicZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/basic_zombie.png");

	public BasicZombieRenderer(class_5617.class_5618 context) {
		super(context, new BasicZombieModel(context.method_32167(ModModelLayers.Zombie.BASIC_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(BasicZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(BasicZombieRenderState state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int i) {
		super.method_4054(state, matrixStack, vertexConsumerProvider, i);
	}

	@Override
	public BasicZombieRenderState method_55269() {
		return new BasicZombieRenderState();
	}

	@Override
	public void updateRenderState(BasicZombieEntity entity, BasicZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/BasicZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.client.plant.PeashooterRenderState;
import net.db64.homelawnsecurity.entity.custom.plant.PeashooterEntity;
import net.db64.homelawnsecurity.entity.custom.zombie.BasicZombieEntity;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class BasicZombieRenderer extends class_927<BasicZombieEntity, BasicZombieRenderState, BasicZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/basic_zombie.png");

	public BasicZombieRenderer(class_5617.class_5618 context) {
		super(context, new BasicZombieModel(context.method_32167(ModModelLayers.Zombie.BASIC_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(BasicZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(
		BasicZombieRenderState state,
		class_4587 matrixStack,
		class_11659 orderedRenderCommandQueue,
		class_12075 cameraRenderState
	) {
		super.method_4054(state, matrixStack, orderedRenderCommandQueue, cameraRenderState);
	}

	@Override
	public BasicZombieRenderState method_55269() {
		return new BasicZombieRenderState();
	}

	@Override
	public void updateRenderState(BasicZombieEntity entity, BasicZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}
